%define name    intel-media
%define version 24.3.0
%define rel     0

%define major   7
%define libname %mklibname igfxcmrt %{major}
%define develname %mklibname igfxcmrt -d

Name:           %{name}
Version:        %{version}
Release:        %mkrel %{rel}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Kernel and hardware
License:        MIT
URL:            https://github.com/intel/media-driver
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
#

# patches from git upstream
#
Patch0001:	0001-VP-Update-FPS-tracking-logic.patch
Patch0002:	0002-Revert-Encode-update-ddi-layer.patch
Patch0003:	0003-VP-Move-Reserved-Bit-to-the-End.patch
Patch0004:	0004-VP-Fix-hdr-capture-issue.patch
Patch0005:	0005-Decode-Fix-some-coverity-issues.patch
Patch0006:	0006-VP-Refactor-for-build-issue.patch
Patch0007:	0007-Encode-Potentially-Fix-Render-PF-issue-on-RPLP-platf.patch
Patch0008:	0008-Media-Common-VP-Fix-LNL-build-issue-of-missing-files.patch
Patch0009:	0009-VP-Separate-FP16-and-HDR-Legacy-Code-and-fix-alpha-p.patch
Patch0010:	0010-Media-Common-VP-MCPY-add-support-for-small-local-bar.patch
Patch0011:	0011-VP-Enable-bindless-suface-state-mode.patch
Patch0012:	0012-Encode-Move-common-featurse-to-common-path.patch
Patch0013:	0013-VP-Fix-L0-FC-Alpha-and-Blending.patch
Patch0014:	0014-Add-max-resolution-for-MPEG2-on-Gen12.patch
Patch0015:	0015-Encode-comment-fix.patch
Patch0016:	0016-VP-fix_reuse_params.patch
Patch0017:	0017-VP-Add-LNL-upstream-support-for-cm-kernel.patch
Patch0018:	0018-Media-Common-VP-Fix-linux-long-latency-issue.patch
Patch0019:	0019-Decode-Fix-decode-coverity-issue.patch
Patch0020:	0020-VP-Fix-coverity-issue-for-heap-manager.patch
Patch0021:	0021-Decode-Enable-pat-index-for-prime-buffer.patch
Patch0022:	0023-Decode-LNL-JPEG-cmake-issue-fix.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(igdgmm) >= 12.3.0
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(libva)
BuildRequires:  intel-gmmlib-devel >= 22.3.20

# This package relies on igdgmm which relies on intel asm
ExclusiveArch:  x86_64 

%description
Intel Media SDK provides a plain C API to access hardware-accelerated video
decode, encode and filtering on Intel Gen graphics hardware platforms.
Implementation written in C++ 11 with parts in C-for-Media (CM).

Supported video encoders: HEVC, AVC, MPEG-2, JPEG, VP9 Supported video decoders:
HEVC, AVC, VP8, VP9, MPEG-2, VC1, JPEG Supported video pre-processing filters:
Color Conversion, Deinterlace, Denoise, Resize, Rotate, Composition

%package -n     vaapi-driver-%{name}
Summary:        Hardware-accelerated video processing driver for VAAPI Intel
Group:          System/Kernel and hardware
 
%description -n vaapi-driver-%{name}
This package contains the driver needed to access hardware 
 

%package -n     %{libname}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
 
%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with igfxcmrt library.
 
%package -n     %{develname}
Summary:        SDK for hardware-accelerated video processing on Intel integrated GPUs
Group:          Development/C++
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
 
%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use igfxcmrt library.

%files -n vaapi-driver-%{name}
%{_libdir}/dri/*_drv_video.so
 
%files -n %{libname}
%{_libdir}/libigfxcmrt.so.%{major}{,.*}
 
%files -n %{develname}
%dir %{_includedir}/igfxcmrt
%{_includedir}/igfxcmrt/cm_*.h
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc


%prep
%autosetup -p1 -n media-driver-intel-media-%{version}

%build
%cmake \
    -DBUILD_DISPATCHER=ON \
    -DBUILD_SAMPLES=OFF \
    -DBUILD_TESTS=ON \
    -DBUILD_TOOLS=OFF \
    -DENABLE_OPENCL=ON \
    -DENABLE_WAYLAND=ON \
    -DENABLE_X11=ON \
    -DENABLE_X11_DRI3=ON \
    -DUSE_SYSTEM_GTEST=ON \

%cmake_build

%install
%cmake_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'



%changelog
* Tue Jul 30 2024 ghibo <ghibo> 24.3.0-0.mga10
+ Revision: 2082937
- Update to version 24.3.0.
- Merge patches from git upstream.

* Mon Jul 01 2024 ghibo <ghibo> 24.2.5-1.mga10
+ Revision: 2078523
- Update to release 24.2.5.
- Merge patches from git upstream.
- Fix gmmlib BR.
- Update to version 24.1.5

* Thu Feb 22 2024 ghibo <ghibo> 24.1.3-1.mga10
+ Revision: 2043164
- Update to version 24.1.3.
- Merge patches from git upstream.

* Sat Dec 16 2023 ghibo <ghibo> 23.4.3-1.mga10
+ Revision: 2018325
- Update to version 23.4.3.
- Drop patches merged upstream.

* Tue Sep 19 2023 ghibo <ghibo> 23.3.3-1.mga10
+ Revision: 1988064
- Update to release 23.3.3.
- Merge patches from git upstream.

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-2.mga9
+ Revision: 1949666
- Merge patch from git upstream to fix a memleak

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-1.mga9
+ Revision: 1949643
- Update to release 23.1.3.
- Drop patches merged upstream.

* Sat Feb 25 2023 ghibo <ghibo> 23.1.2-1.mga9
+ Revision: 1945394
- Update to release 23.1.2.
- Merge patch from git upstream to fix jpeg decode MD5 mismatch.
- Merge patch from git upstream to fix NULL pointer issue.

* Thu Feb 09 2023 ghibo <ghibo> 23.1.1-1.mga9
+ Revision: 1939727
- Update to release 23.1.1.
- Drop Patch0, merged upstream.
- Versioning igdgmm in BuildRequires.

* Thu Mar 31 2022 kekepower <kekepower> 22.3.0-1.mga9
+ Revision: 1836901
- Add upstream patch to fix build with gcc 12.0.1
- Update to version 22.3.0
- Update to version 22.1.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jul 10 2020 zezinho <zezinho> 20.2.0-1.mga8
+ Revision: 1604322
- new version 20.2.0

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-2.mga8
+ Revision: 1565321
- fix url

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-1.mga8
+ Revision: 1565275
- imported package intel-media

